pub struct FileOperations {}Implementations
Sourceimpl FileOperations
impl FileOperations
pub async fn open_path( data_dir: &Path, page_id: &PageId, file_number: usize, ) -> Result<File, FileOperationsError>
Sourcepub async fn add_chunk(
file: &mut File,
page_offset: &PageOffset,
buffer: Bytes,
) -> Result<(), FileOperationsError>
pub async fn add_chunk( file: &mut File, page_offset: &PageOffset, buffer: Bytes, ) -> Result<(), FileOperationsError>
Note the File Handle AND PageOffset should point to where the add should occur If the file is larger than requested nothing is done.
pub async fn make_sub_path( data_dir: &Path, page_id: &PageId, ) -> Result<PathBuf, FileOperationsError>
pub async fn read_chunk( file: &mut File, page_offset: &PageOffset, ) -> Result<Bytes, FileOperationsError>
pub async fn update_chunk( file: &mut File, page_offset: &PageOffset, buffer: Bytes, ) -> Result<(), FileOperationsError>