LockManager

Struct LockManager 

pub struct LockManager { /* private fields */ }
The LockManager is used for cooperative access to pages in the system.

Before accessing the I/O layer you must get a read or write lock on the page you need to access. Only AFTER you have the lock you should ask for the page.

Implementations

Source

impl LockManager

pub fn new() -> LockManager

pub async fn read( &self, page_id: PageId, offset: PageOffset, ) -> OwnedRwLockReadGuard<(PageId, PageOffset)>

pub async fn write( &self, page_id: PageId, offset: PageOffset, ) -> OwnedRwLockWriteGuard<(PageId, PageOffset)>